MacroBetaHirukawaTSKernel generator methodUser friendly constructor method for MacroBetaHirukawaTSKernel objects.
macroBetaHirukawaTSKernel(dataPoints, c, b=length(dataPoints)^(-2/5),
dataPointsCache=NULL, modified = FALSE, lower.limit = 0,
upper.limit = 1)a numeric vector containing data samples within the [lower.limit,upper.limit] interval. These data samples are used to obtain the kernel estimator
a numeric value between 0 and 1. This parameter is used in the TS approximation as a smoothing parameter
the bandwidth of the kernel estimator
a numeric vector containing points within the [lower.limit,upper.limit] interval. These points are used for convenience to cache density and distribution values. If dataPointsCache=NULL the values are initialized to a sequence of 101 equally spaced values from lower.limit to upper.limit
if TRUE, the modified version of the kernel estimator is used
a numeric value for the lower limit of the bounded interval for the data
a numeric value for the upper limit of the bounded interval for the data. That is, the data is with the [lower.limit,upper.limit] interval